.. _credits:
.. index:: Credits

Credits
*******

**icet** has been developed at the Department of Physics at Chalmers University of Technology (Gothenburg, Sweden), in collaboration with the Data Analysis group at the `Data Management and Software Center of the European Spallation Source <https://europeanspallationsource.se/data-management-software#data-analysis-modelling>`_ (Copenhagen, Denmark).
The `conda-forge` recipes have been generously set up by `Jan Janssen <https://github.com/jan-janssen/>`_ at the *Max-Planck-Institut für Eisenforschung* (Düsseldorf, Germany).

When using :program:`icet` in your research please cite the following paper:

| M. Ångqvist, W. A. Muñoz, J. M. Rahm, E. Fransson, C. Durniak, P. Rozyczko, T. H. Rod, and P. Erhart
| *ICET – A Python Library for Constructing and Sampling Alloy Cluster Expansions*
| Advanced Theory and Simulations, 1900015 (2019)
| `doi: 10.1002/adts.201900015 <https://doi.org/10.1002/adts.201900015>`_

You should also cite relevant background literature.
The following list provides an incomplete set of examples.
Please also consult the `bibliography page <bibliography` and the original papers to ensure that credit is given where credit is due.


Structure enumeration
---------------------

| G. L. W. Hart and R. W. Forcade
| *Algorithm for generating derivative structures*
| Physical Review B **77**, 224115 (2008)
| `doi: 10.1103/PhysRevB.77.224115 <http://dx.doi.org/10.1103/PhysRevB.77.224115>`_

| G. L. W. Hart and R. W. Forcade
| *Generating derivative structures from multilattices: Algorithm and application to hcp alloys*
| Physical Review B **80**, 014120 (2009)
| `doi: 10.1103/PhysRevB.80.014120 <http://dx.doi.org/10.1103/PhysRevB.80.014120>`_


Special quasi-random structures
-------------------------------

| A. Zunger, S.-H. Wei, L. G. Ferreira, and J. E. Bernard.
| *Special quasirandom structures*
| Physical Review Letters **65**, 353 (1990)
| `doi: 10.1103/PhysRevLett.65.353 <http://dx.doi.org/10.1103/PhysRevLett.65.353>`_

| A. van de Walle, P. Tiwary, M. de Jong, D.L. Olmsted, M. Asta, A. Dick, D. Shin, Y. Wang, L.-Q. Chen, and Z.-K. Liu
| *Efficient stochastic generation of special quasirandom structures*
| Calphad *42*, 13 (2013)
| `doi: 10.1016/j.calphad.2013.06.006 <http://dx.doi.org/10.1016/j.calphad.2013.06.006>`_


Ground state finding via MIP
----------------------------
| P. M. Larsen, K. W. Jacobsen, and J. Schiøtz
| *Rich Ground-State Chemical Ordering in Nanoparticles: Exact Solution of a Model for Ag-Au Clusters*
| Physical Review Letters **120**, 256101 (2018)
| `doi: 10.1103/PhysRevLett.120.256101 <https://doi.org/10.1103/PhysRevLett.120.256101>`_


MC simulations in the variance-constrained semi-grandcanonical ensemble
-----------------------------------------------------------------------

| B. Sadigh, and P. Erhart
| *Calculation of excess free energies of precipitates via direct thermodynamic integration across phase boundaries*
| Physical Review B **86**, 134204 (2012)
| `doi: 10.1103/PhysRevB.86.134204 <http://dx.doi.org/10.1103/PhysRevB.86.134204>`_


Bayesian cluster expansions
---------------------------

| T. Mueller and G. Ceder
| *Bayesian approach to cluster expansions*
| Physical Review B **80**, 024103 (2009)
| `doi: 10.1103/PhysRevB.80.024103 <https://doi.org/10.1103/PhysRevB.80.024103>`_


Merging orbits
--------------

| P. Ekborg-Tanner and P. Erhart
| *Hydrogen-driven Surface Segregation in Pd-alloys from Atomic Scale Simulations*
| Journal of Physical Chemistry C **125**, 17248 (2021)
| `doi: 10.1021/acs.jpcc.1c00575 <https://doi.org/10.1021/acs.jpcc.1c00575>`_


Cluster expansions with strain
------------------------------

| D. B. Laks, L. G. Ferreira, S. Froyen, and A. Zunger
| *Efficient cluster expansion for substitutional systems*
| Phys. Rev. B **46**, 12587 (1992)
| `doi: 10.1103/PhysRevB.46.12587 <https://doi.org/10.1103/PhysRevB.46.12587>`_

| J. M. Rahm, J. Löfgren, and P. Erhart
| *Quantitative predictions of thermodynamic hysteresis: Temperature-dependent character of the phase transition in Pd–H*
| `arxiv:2110.07883 <https://arxiv.org/abs/2110.07883>`_
